@@ -324,6 +324,9 @@ class InstallImageMagick(InstallPackage):
 class InstallHttpie(InstallPackage):
     package_name = brew_name = apt_name = "httpie"
 
+class InstallScipy(InstallPackage):
+    package_name = brew_name = apt_name = "scipy"
+
 class GHAuthentication(SetupTask):
     description = "Sign in to github"
     gh_auth_file = Path.home() / ".config/gh/hosts.yml"
